Class: GrapeTokenAuth::LookupToken

Inherits:
Object
  • Object
show all
Extended by:
ClassMethods
Defined in:
lib/grape_token_auth/lookup_token.rb

Overview

Look up tokens are a type of token that allows searching by that token. This is useful in use cases such as confirmation tokens. These type of tokens are not appropriate for auth. In auth, look up is done via uid and verification/persitance with BCrypt. In short, this is a utility class that should not be used unless you are sure of your need.

Defined Under Namespace

Modules: ClassMethods

Method Summary

Methods included from ClassMethods

digest, friendly_token, generate, open_ssl_digest