Exception: GrapeTokenAuth::ScopeUndefinedError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/grape_token_auth/exceptions.rb

Overview

Error when an undefined scope was attempted to be used

Instance Method Summary collapse

Constructor Details

#initialize(msg, scope = nil) ⇒ ScopeUndefinedError

Returns a new instance of ScopeUndefinedError.



5
6
7
8
9
10
# File 'lib/grape_token_auth/exceptions.rb', line 5

def initialize(msg, scope = nil)
  msg ||= "Trying to use an undefined scope #{scope}. A proper \
           scope to resource class mapping must be set up in the \
           GrapeTokenAuth configuration."
  super(msg)
end